"use client"

import {
  FolderIcon,
  FolderOpenIcon,
  HomeIcon,
  ImageIcon,
  InfoIcon,
  LayersIcon,
  TagIcon,
  UserIcon,
} from "lucide-react"
import Link from "next/link"
import { usePathname } from "next/navigation"
import { Fragment, JSX } from "react"

const iconMap: Record<string, JSX.Element> = {
  "about": <InfoIcon className="w-4 h-4" />,
  "artists": <UserIcon className="w-4 h-4" />,
  "categories": <LayersIcon className="w-4 h-4" />,
  "tags": <TagIcon className="w-4 h-4" />,
  "gallery": <FolderIcon className="w-4 h-4" />,
  "album": <FolderOpenIcon className="w-4 h-4" />,
  "image": <ImageIcon className="w-4 h-4" />,
}

export default function Breadcrumbs() {
  const pathname = usePathname()
  const rawSegments = pathname.split("/").filter(Boolean)

  // If path is just "/", return nothing
  if (rawSegments.length === 0) return null

  // Special handling: remove "galleries" from breadcrumb trail
  const segments = rawSegments.filter((seg, index) =>
    !(seg === "galleries" && index === 0)
  )

  return (
    <div className="text-sm px-1 text-muted-foreground flex items-center flex-wrap gap-1">
      <Link href="/" className="inline-flex items-center gap-1 hover:underline font-medium text-foreground">
        <HomeIcon className="w-4 h-4" />
        Home
      </Link>

      {segments.length > 0 && <span>{">"}</span>}

      {segments.map((seg, i) => {
        const href = "/" + rawSegments.slice(0, rawSegments.indexOf(seg) + 1).join("/")
        const isLast = i === segments.length - 1
        const icon = iconMap[rawSegments[0]] || null

        return (
          <Fragment key={href}>
            {i > 0 && <span>{">"}</span>}
            {isLast ? (
              <span className="inline-flex items-center gap-1 font-medium text-foreground">
                {i === 0 && icon}
                {decodeURIComponent(seg)}
              </span>
            ) : (
              <Link
                href={href}
                className="inline-flex items-center gap-1 hover:underline"
              >
                {i === 0 && icon}
                {decodeURIComponent(seg)}
              </Link>
            )}
          </Fragment>
        )
      })}
    </div>
  )
}
